
close all;

% computational domain
NX = 2048;
cx = linspace(0,NX-1,NX);

% parameters
la = 25;
k0 = 2.0/la;
w0 = 5.0*la;

% define initial electric field fucntion
InitialE = @(x,x0) sin(k0*x).*exp(-(x-x0).*(x-x0)/w0^2);

% choose time step:
dtoverdx = 0.75;

NS = 4096/16;

accumulator = zeros(NS,NX);

for k=1:50

figure(1);
hold off;

% set white-noise initial condition
EF = rand(1,NX)-0.5;
HF = rand(1,NX)-0.5;

holder = zeros(NS,NX);

% execute some steps
for s=1:NS
EF = EF + dtoverdx*(circshift(HF,[1,-1]) - HF);
HF = HF - dtoverdx*(circshift(EF,[1,+1]) - EF);

holder(s,:) = EF;

%plot(cx,EF);
%pause(0.01);
end

% accumulate spectral power for averaging
spectrum = fft2(holder);
accumulator = accumulator + spectrum.^2;

% show moving-average spectral power
imagesc(log10(abs(accumulator))); colorbar;
display(k);

end

% physical axes 
omegaaxis = linspace(-NS/2,NS/2,NS)*2*pi/(NS*dtoverdx);
wavenaxis = linspace(-NX/2,NX/2,NX)*2*pi/(NX*1);

% show after fftshift
figure(2);
imagesc(wavenaxis,omegaaxis,log10(abs(fftshift(accumulator)))); colorbar;
xlabel('spatial wavenumber');
ylabel('angular frequency');


